##  Prerequisites
Before you start, do the following:
  * Learn about the SSO configuration process in [SSO Configuration Process](https://help.sap.com/docs/leanix/ea/sso-configuration-process?locale=en-US&state=PRODUCTION&version=CLOUD).
